@@ -12,7 +12,6 @@ from plinth.config import DropinConfigs
 from plinth.daemon import Daemon
 from plinth.modules.apache.components import Webserver
 from plinth.modules.backups.components import BackupRestore
-from plinth.modules.config import get_domainname
 from plinth.modules.firewall.components import (Firewall,
                                                 FirewallLocalProtection)
 from plinth.modules.letsencrypt.components import LetsEncrypt
@@ -64,7 +63,7 @@ class EmailApp(plinth.app.App):
                                icon_filename='email',
                                short_description=_('Email Server'),
                                description=_description, manual_page='Email',
-                               clients=manifest.clients,
+                               clients=manifest.clients, tags=manifest.tags,
                                donation_url='https://rspamd.com/support.html')
         self.add(info)
 
@@ -223,12 +222,6 @@ class EmailApp(plinth.app.App):
             self.enable()
 
 
-def get_domains():
-    """Return the list of domains configured."""
-    default_domain = get_domainname()
-    return [default_domain] if default_domain else []
-
-
 def _get_first_admin():
     """Return an admin user in the system or None if non exist."""
     from django.contrib.auth.models import User
