@@ -40,7 +40,7 @@ class MediaWikiApp(app_module.App):
 
     app_id = 'mediawiki'
 
-    _version = 12
+    _version = 13
 
     def __init__(self) -> None:
         """Create components for the app."""
@@ -52,7 +52,8 @@ class MediaWikiApp(app_module.App):
                                short_description=_('Wiki'),
                                description=_description,
                                manual_page='MediaWiki',
-                               clients=manifest.clients)
+                               clients=manifest.clients,
+                               tags=manifest.tags)
         self.add(info)
 
         menu_item = menu.Menu('menu-mediawiki', info.name,
@@ -86,7 +87,7 @@ class MediaWikiApp(app_module.App):
         self.add(webserver)
 
         webserver = Webserver('webserver-mediawiki-freedombox',
-                              'mediawiki-freedombox')
+                              'mediawiki-freedombox', last_updated_version=13)
         self.add(webserver)
 
         daemon = Daemon('daemon-mediawiki', 'mediawiki-jobrunner')
