@@ -10,28 +10,11 @@ from plinth import app as app_module
 from plinth import daemon, kvstore, menu, network
 from plinth.config import DropinConfigs
 from plinth.diagnostic_check import DiagnosticCheck
+from plinth.modules.firewall.components import Firewall
 from plinth.package import Packages
 
 from . import privileged
 
-first_boot_steps = [
-    {
-        'id': 'network_topology_wizard',
-        'url': 'networks:network-topology-first-boot',
-        'order': 2,
-    },
-    {
-        'id': 'router_setup_wizard',
-        'url': 'networks:router-configuration-first-boot',
-        'order': 3,
-    },
-    {
-        'id': 'internet_connectivity_type_wizard',
-        'url': 'networks:internet-connection-type-first-boot',
-        'order': 4,
-    },
-]
-
 _description = [
     _('Configure network devices. Connect to the Internet via Ethernet, Wi-Fi '
       'or PPPoE. Share that connection with other devices on the network.'),
@@ -69,6 +52,11 @@ class NetworksApp(app_module.App):
         packages = Packages('packages-networks', ['network-manager', 'batctl'])
         self.add(packages)
 
+        # For 'shared' network connections
+        firewall = Firewall('firewall-networks', info.name,
+                            ports=['dns', 'dhcp'], is_external=False)
+        self.add(firewall)
+
         dropin_configs = DropinConfigs('dropin-configs-networks', [
             '/etc/NetworkManager/dispatcher.d/10-freedombox-batman',
         ])
