@@ -20,6 +20,7 @@ SERVICE_NAME = 'nextcloud-freedombox'
 VOLUME_NAME = 'nextcloud-freedombox'
 IMAGE_NAME = 'docker.io/library/nextcloud:stable-fpm'
 
+WWW_DATA_UID = '33'
 DB_HOST = 'localhost'
 DB_NAME = 'nextcloud_fbx'
 DB_USER = 'nextcloud_fbx'
@@ -76,7 +77,7 @@ def _run_in_container(
         env: dict[str, str] | None = None) -> subprocess.CompletedProcess:
     """Run a command inside the container."""
     env_args = [f'--env={key}={value}' for key, value in (env or {}).items()]
-    command = ['podman', 'exec', '--user', 'www-data'
+    command = ['podman', 'exec', '--user', WWW_DATA_UID
                ] + env_args + [CONTAINER_NAME] + list(args)
     return subprocess.run(command, capture_output=capture_output, check=check)
 
@@ -119,7 +120,7 @@ def get_override_domain():
 def set_override_domain(domain_name: str):
     """Set the domain name that Nextcloud will use to override all domains."""
     protocol = 'https'
-    if domain_name.endswith('.onion'):
+    if domain_name.endswith('.onion') or not domain_name:
         protocol = 'http'
 
     if domain_name:
@@ -130,7 +131,8 @@ def set_override_domain(domain_name: str):
     else:
         _run_occ('config:system:delete', 'overwritehost')
         _run_occ('config:system:delete', 'overwriteprotocol')
-        _run_occ('config:system:delete', 'overwrite.cli.url')
+        _run_occ('config:system:set', 'overwrite.cli.url', '--value',
+                 f'{protocol}://localhost/nextcloud')
 
     # Restart to apply changes immediately
     action_utils.service_restart('nextcloud-freedombox')
@@ -200,12 +202,33 @@ def _set_database_privileges(db_password: str):
 
 def _nextcloud_wait_until_ready():
     """Wait for Nextcloud container to get ready."""
+
+    def _versions_match():
+        """Return if versions in shipped and runtime directories match.
+
+        Nextcloud container ships with source in /usr/source/nextcloud. This is
+        copied to /var/www/html/ when there is a mismatch between their
+        version.php. The last step in the coping process is the copy of
+        version.php file itself.
+        """
+        try:
+            source_version = '/usr/src/nextcloud/version.php'
+            runtime_version = '/var/www/html/version.php'
+            _run_in_container('diff', source_version, runtime_version)
+            return True
+        except subprocess.CalledProcessError:
+            return False
+
     # Nextcloud copies sources from /usr/src/nextcloud to /var/www/html inside
     # the container. Nextcloud is served from the latter location. This happens
-    # on first run of the container and when upgrade happen.
+    # on first run of the container and when upgrade happen. Checking for
+    # existence of version.php is easy and works for first install. For
+    # upgrades, we must wait until source is copied to the runtime directory.
+    # The last file to be copied the version.php. Only after this is checking
+    # for the lock file below meaningful.
     start_time = time.time()
     while time.time() < start_time + 300:
-        if (_data_path / 'version.php').exists():
+        if (_data_path / 'version.php').exists() and _versions_match():
             break
 
         time.sleep(1)
